
# These tests were created to satisfy Devel::Cover reports.  They are not
# exhaustive and should not be considered as a complete test case.

use Test::Most tests => 2;
use Test::NoWarnings;

BEGIN { use_ok( 'Net::Google::GData' ) }

